
# Odoo Backup Tool

_**ORH** Command Line Tool_

![PyPI](https://img.shields.io/pypi/v/odoo-backup-tool) ![PyPI](https://img.shields.io/pypi/pyversions/odoo-backup-tool)

## Requirements



## Installation

Install from PyPI:
```bash
pip install odoo-backup-tool
```

## Quickstart


### Backup local database
```bash
obt backup DBNAME
```

### Backup and upload
```bash
obt backup-and-push --format zip [DBNAME]
```